@@ -110,7 +110,7 @@ public class DICOM extends ImagePlus implements PlugIn {
 		}
 		if (fi!=null && fi.width>0 && fi.height>0 && fi.offset>0) {
 			FileOpener fo = new FileOpener(fi);
-			ImagePlus imp = fo.open(false);
+			ImagePlus imp = fo.openImage();
 			ImageProcessor ip = imp.getProcessor();
 			if (Prefs.openDicomsAsFloat) {
 				ip = ip.convertToFloat();
@@ -302,6 +302,13 @@ class DicomDecoder {
 		return new String(buf);
 	}
   
+	String getUNString(int length) throws IOException {
+		String s = getString(length);
+		if (s!=null && s.length()>60)
+			s = s.substring(0,60);
+		return s;
+	}
+
 	int getByte() throws IOException {
 		int b = f.read();
 		if (b ==-1)
@@ -318,6 +325,15 @@ class DicomDecoder {
 		else
 			return ((b0 << 8) + b1);
 	}
+	
+	int getSShort() throws IOException {
+		short b0 = (short)getByte();
+		short b1 = (short)getByte();
+		if (littleEndian)
+			return ((b1 << 8) + b0);
+		else
+			return ((b0 << 8) + b1);
+	}
   
 	final int getInt() throws IOException {
 		int b0 = getByte();
@@ -329,6 +345,17 @@ class DicomDecoder {
 		else
 			return ((b0<<24) + (b1<<16) + (b2<<8) + b3);
 	}
+	
+	long getUInt() throws IOException {
+		long b0 = getByte();
+		long b1 = getByte();
+		long b2 = getByte();
+		long b3 = getByte();
+		if (littleEndian)
+			return ((b3<<24) + (b2<<16) + (b1<<8) + b0);
+		else
+			return ((b0<<24) + (b1<<16) + (b2<<8) + b3);
+	}
 
 	double getDouble() throws IOException {
 		int b0 = getByte();
@@ -770,6 +797,9 @@ class DicomDecoder {
 			case LT: case PN: case SH: case ST: case TM: case UI:
 				value = getString(elementLength);
 				break;
+			case UN:
+				value = getUNString(elementLength);
+				break;
 			case US:
 				if (elementLength==2)
 					value = Integer.toString(getShort());
@@ -783,6 +813,45 @@ class DicomDecoder {
 					value = sb.toString();
 				}
 				break;
+			case SS:
+				if (elementLength==2)
+					value = Integer.toString(getSShort());
+				else {
+					int n = elementLength/2;
+					StringBuilder sb = new StringBuilder();
+					for (int i=0; i<n; i++) {
+						sb.append(Integer.toString(getSShort()));
+						sb.append(" ");
+					}
+					value = sb.toString();
+				}
+				break;
+			case UL:
+				if (elementLength==4)
+					value = Long.toString(getUInt());
+				else {
+					int n = elementLength/4;
+					StringBuilder sb = new StringBuilder();
+					for (int i=0; i<n; i++) {
+						sb.append(Long.toString(getUInt()));
+						sb.append(" ");
+					}
+					value = sb.toString();
+				}
+				break;
+			case SL:
+				if (elementLength==4)
+					value = Long.toString(getInt());
+				else {
+					int n = elementLength/4;
+					StringBuilder sb = new StringBuilder();
+					for (int i=0; i<n; i++) {
+						sb.append(Long.toString(getInt()));
+						sb.append(" ");
+					}
+					value = sb.toString();
+				}
+				break;
 			case IMPLICIT_VR:
 				value = getString(elementLength);
 				if (elementLength>44) value=null;
