@@ -23,18 +23,27 @@ public class FolderOpener implements PlugIn {
 	private double scale = 100.0;
 	private int n, start, increment;
 	private String filter;
-	private boolean isRegex;
 	private String legacyRegex;
 	private FileInfo fi;
 	private String info1;
 	private ImagePlus image;
 	private boolean saveImage;
+	private long t0;
 	
 	/** Opens the images in the specified directory as a stack. Displays
 		directory chooser and options dialogs if the argument is null. */
 	public static ImagePlus open(String path) {
+		return open(path, null);
+	}
+
+	/** Opens the images in the specified directory as a stack. Opens
+		the images as a virtual stack if the 'options' string contains
+		"virtual". Displays directory chooser and options dialogs if the
+		the 'path' argument is null. */
+	public static ImagePlus open(String path, String options) {
 		FolderOpener fo = new FolderOpener();
 		fo.saveImage = true;
+		fo.openAsVirtualStack = options!=null && options.contains("virtual");
 		fo.run(path);
 		return fo.image;
 	}
@@ -48,17 +57,18 @@ public class FolderOpener implements PlugIn {
 	}
 
 	public void run(String arg) {
+		boolean isMacro = Macro.getOptions()!=null;
 		String directory = null;
 		if (arg!=null && !arg.equals("")) {
 			directory = arg;
 		} else {
-			if (!IJ.macroRunning()) {
+			if (!isMacro) {
 				sortFileNames = staticSortFileNames;
 				openAsVirtualStack = staticOpenAsVirtualStack;
 			}
 			arg = null;
 			String title = "Open Image Sequence...";
-			String macroOptions = IJ.macroRunning()?Macro.getOptions():null;
+			String macroOptions = Macro.getOptions();
 			if (macroOptions!=null) {
 				directory = Macro.getValue(macroOptions, title, null);
 				if (directory!=null) {
@@ -107,63 +117,46 @@ public class FolderOpener implements PlugIn {
 		boolean allSameCalibration = true;
 		IJ.resetEscape();		
 		Overlay overlay = null;
+		n = list.length;
+		start = 1;
+		increment = 1;
 		try {
-			for (int i=0; i<list.length; i++) {
-				Opener opener = new Opener();
-				opener.setSilentMode(true);
-				IJ.redirectErrorMessages(true);
-				ImagePlus imp = opener.openImage(directory, list[i]);
-				IJ.redirectErrorMessages(false);
-				if (imp!=null) {
-					width = imp.getWidth();
-					height = imp.getHeight();
-					bitDepth = imp.getBitDepth();
-					fi = imp.getOriginalFileInfo();
-					if (arg==null) {
-						if (!showDialog(imp, list))
-							return;
-					} else {
-						n = list.length;
-						start = 1;
-						increment = 1;
+			if (isMacro) {
+				if (!showDialog(null, list))
+					return;
+			} else {
+				for (int i=0; i<list.length; i++) {
+					Opener opener = new Opener();
+					opener.setSilentMode(true);
+					IJ.redirectErrorMessages(true);
+					ImagePlus imp = opener.openImage(directory, list[i]);
+					IJ.redirectErrorMessages(false);
+					if (imp!=null) {
+						width = imp.getWidth();
+						height = imp.getHeight();
+						bitDepth = imp.getBitDepth();
+						if (arg==null) {
+							if (!showDialog(imp, list))
+								return;
+						}
+						break;
 					}
-					break;
+				}
+				if (width==0) {
+					IJ.error("Sequence Reader", "This folder does not appear to contain\n"
+					+ "any TIFF, JPEG, BMP, DICOM, GIF, FITS or PGM files.\n \n"
+					+ "   \""+directory+"\"");
+					return;
 				}
 			}
-			if (width==0) {
-				IJ.error("Sequence Reader", "This folder does not appear to contain\n"
-				+ "any TIFF, JPEG, BMP, DICOM, GIF, FITS or PGM files.\n \n"
-				+ "   \""+directory+"\"");
+			String pluginName = "Sequence Reader";
+			if (legacyRegex!=null)
+				pluginName += "(legacy)";
+			list = getFilteredList(list, filter, pluginName);
+			if (list==null)
 				return;
-			}
-
-			if (filter!=null && (filter.equals("") || filter.equals("*")))
-				filter = null;
-			if (filter!=null) {
-				int filteredImages = 0;
-  				for (int i=0; i<list.length; i++) {
-					if (isRegex && containsRegex(list[i],filter))
-						filteredImages++;
-					else if (list[i].contains(filter))
-						filteredImages++;
- 					else
- 						list[i] = null;
- 				}
-  				if (filteredImages==0) {
-  					if (isRegex)
-  						IJ.error("Sequence Reader", "None of the file names contain the regular expression.");
-  					else
-   						IJ.error("Sequence Reader", "None of the "+list.length+" files contain\n the string '"+filter+"' in their name.");
- 					return;
-  				}
-  				String[] list2 = new String[filteredImages];
-  				int j = 0;
-  				for (int i=0; i<list.length; i++) {
- 					if (list[i]!=null)
- 						list2[j++] = list[i];
- 				}
-  				list = list2;
-  			}
+			IJ.showStatus("");
+			t0 = System.currentTimeMillis();
 			if (sortFileNames)
 				list = StringSorter.sortNumerically(list);
 
@@ -177,6 +170,7 @@ public class FolderOpener implements PlugIn {
 			int counter = 0;
 			ImagePlus imp = null;
 			boolean firstMessage = true;
+			boolean fileInfoStack = false;
 			for (int i=start-1; i<list.length; i++) {
 				if ((counter++%increment)!=0)
 					continue;
@@ -186,18 +180,28 @@ public class FolderOpener implements PlugIn {
 				if ("RoiSet.zip".equals(list[i])) {
 					IJ.open(directory+list[i]);
 					imp = null;
-				} else if (!openAsVirtualStack||stack==null)
+				} else if (!openAsVirtualStack||stack==null) {
 					imp = opener.openImage(directory, list[i]);
+					stackSize = imp!=null?imp.getStackSize():1;
+				}
 				IJ.redirectErrorMessages(false);
 				if (imp!=null && stack==null) {
 					width = imp.getWidth();
 					height = imp.getHeight();
 					bitDepth = imp.getBitDepth();
+					fi = imp.getOriginalFileInfo();
+					ImageProcessor ip = imp.getProcessor();
+					min = ip.getMin();
+					max = ip.getMax();
 					cal = imp.getCalibration();
 					if (convertToRGB) bitDepth = 24;
 					ColorModel cm = imp.getProcessor().getColorModel();
 					if (openAsVirtualStack) {
-						stack = new VirtualStack(width, height, cm, directory);
+						if (stackSize>1) {
+							stack = new FileInfoVirtualStack();
+							fileInfoStack = true;
+						} else
+							stack = new VirtualStack(width, height, cm, directory);
 						((VirtualStack)stack).setBitDepth(bitDepth);
 					} else if (scale<100.0)						
 						stack = new ImageStack((int)(width*scale/100.0), (int)(height*scale/100.0), cm);
@@ -207,7 +211,6 @@ public class FolderOpener implements PlugIn {
 				}
 				if (imp==null)
 					continue;
-				stackSize = imp.getStackSize();
 				if (imp.getWidth()!=width || imp.getHeight()!=height) {
 					IJ.log(list[i] + ": wrong size; "+width+"x"+height+" expected, "+imp.getWidth()+"x"+imp.getHeight()+" found");
 					continue;
@@ -218,7 +221,7 @@ public class FolderOpener implements PlugIn {
 					if (info!=null)
 						label += "\n" + info;
 				}
-				if (imp.getCalibration().pixelWidth!=cal.pixelWidth)
+				if (Math.abs(imp.getCalibration().pixelWidth-cal.pixelWidth)>0.0000000001)
 					allSameCalibration = false;
 				ImageStack inputStack = imp.getStack();
 				Overlay overlay2 = imp.getOverlay();
@@ -233,18 +236,25 @@ public class FolderOpener implements PlugIn {
 						overlay.add(roi);
 					}
 				}
-				for (int slice=1; slice<=stackSize; slice++) {
-					ImageProcessor ip = inputStack.getProcessor(slice);
-					String label2 = label;
-					if (stackSize>1) {
-						String sliceLabel = inputStack.getSliceLabel(slice);
-						if (sliceLabel!=null)
-							label2=sliceLabel;
-						else if (label2!=null && !label2.equals(""))
-							label2 += ":"+slice;
-					}
-					int bitDepth2 = imp.getBitDepth();
-					if (!openAsVirtualStack) {
+				
+				if (openAsVirtualStack) { 
+					if (fileInfoStack)
+						openAsFileInfoStack((FileInfoVirtualStack)stack, directory+list[i]);
+					else
+						((VirtualStack)stack).addSlice(list[i]);
+				} else {
+					for (int slice=1; slice<=stackSize; slice++) {
+						int bitDepth2 = imp.getBitDepth();
+						String label2 = label;
+						ImageProcessor ip = null;
+						if (stackSize>1) {
+							String sliceLabel = inputStack.getSliceLabel(slice);
+							if (sliceLabel!=null)
+								label2=sliceLabel;
+							else if (label2!=null && !label2.equals(""))
+								label2 += ":"+slice;
+						}
+						ip = inputStack.getProcessor(slice);
 						if (convertToRGB) {
 							ip = ip.convertToRGB();
 							bitDepth2 = 24;
@@ -265,30 +275,20 @@ public class FolderOpener implements PlugIn {
 							IJ.log(list[i] + ": wrong bit depth; "+bitDepth+" expected, "+bitDepth2+" found");
 							break;
 						}
-					}
-					if (slice==1) count++;
-					IJ.showStatus(count+"/"+n);
-					IJ.showProgress(count, n);
-					if (scale<100.0)
-						ip = ip.resize((int)(width*scale/100.0), (int)(height*scale/100.0));
-					if (ip.getMin()<min) min = ip.getMin();
-					if (ip.getMax()>max) max = ip.getMax();
-					//if (depth>1) label2 = null;
-					if (openAsVirtualStack) {
-						if (slice==1)
-							((VirtualStack)stack).addSlice(list[i]);
-						else if (slice==2 && firstMessage) {
-							IJ.log(list[i] + " ["+stackSize+"]: only the first slice will be used in virtual stack");
-							firstMessage = false;
-						}
-					} else
+						if (scale<100.0)
+							ip = ip.resize((int)(width*scale/100.0), (int)(height*scale/100.0));
+						if (ip.getMin()<min) min = ip.getMin();
+						if (ip.getMax()>max) max = ip.getMax();
 						stack.addSlice(label2, ip);
+					}
 				}
-				if (count>=n)
+				count++;
+				IJ.showStatus(count+"/"+n);
+				IJ.showProgress(count, n);
+				if (count>=n) 
 					break;
 				if (IJ.escapePressed())
 					{IJ.beep(); break;}
-				//System.gc();
 			}
 		} catch(OutOfMemoryError e) {
 			IJ.outOfMemory("FolderOpener");
@@ -313,12 +313,6 @@ public class FolderOpener implements PlugIn {
 				}
 				if (cal.pixelWidth!=1.0 && cal.pixelDepth==1.0)
 					cal.pixelDepth = cal.pixelWidth;
-				if (cal.pixelWidth<=0.0001 && cal.getUnit().equals("cm")) {
-					cal.pixelWidth *= 10000.0;
-					cal.pixelHeight *= 10000.0;
-					cal.pixelDepth *= 10000.0;
-					cal.setUnit("um");
-				}
 				imp2.setCalibration(cal);
 			}
 			if (info1!=null && info1.lastIndexOf("7FE0,0010")>0) {
@@ -337,7 +331,8 @@ public class FolderOpener implements PlugIn {
 					imp2.setProperty("Info", info1);
 			}
 			if (arg==null && !saveImage) {
-				imp2.show();
+				String time = (System.currentTimeMillis()-t0)/1000.0 + " seconds";
+				imp2.show(time);
 				if (stack.isVirtual()) {
 					overlay = stack.getProcessor(1).getOverlay();
 					if (overlay!=null)
@@ -350,6 +345,23 @@ public class FolderOpener implements PlugIn {
 		IJ.showProgress(1.0);
 	}
 	
+	private void openAsFileInfoStack(FileInfoVirtualStack stack, String path) {
+		FileInfo[] info = Opener.getTiffFileInfo(path);
+		if (info==null || info.length==0)
+			return;
+		int n =info[0].nImages;
+		if (info.length==1 && n>1) {
+			long size = fi.width*fi.height*fi.getBytesPerPixel();
+			for (int i=0; i<n; i++) {
+				FileInfo fi = (FileInfo)info[0].clone();
+				fi.nImages = 1;
+				fi.longOffset = fi.getOffset() + i*(size + fi.gapBetweenImages);
+				stack.addImage(fi);
+			}
+		} else
+			stack.addImage(info[0]);
+	}
+	
 	boolean showDialog(ImagePlus imp, String[] list) {
 		int fileCount = list.length;
 		FolderOpenerDialog gd = new FolderOpenerDialog("Sequence Options", imp, list);
@@ -378,11 +390,8 @@ public class FolderOpener implements PlugIn {
 		if (scale<5.0) scale = 5.0;
 		if (scale>100.0) scale = 100.0;
 		filter = gd.getNextString();
-		filter = checkForRegex(filter);
-		if (legacyRegex!=null) {
-			filter = legacyRegex;
-			isRegex = true;
-		}
+		if (legacyRegex!=null)
+			filter = "("+legacyRegex+")";
 		convertToRGB = gd.getNextBoolean();
 		sortFileNames = gd.getNextBoolean();
 		openAsVirtualStack = gd.getNextBoolean();
@@ -394,22 +403,56 @@ public class FolderOpener implements PlugIn {
 		}
 		return true;
 	}
-
-	private String checkForRegex(String filter) {
+	
+	public static String[] getFilteredList(String[] list, String filter, String title) {
+		boolean isRegex = false;
+		if (filter!=null && (filter.equals("") || filter.equals("*")))
+			filter = null;
+		if (list==null || filter==null)
+			return list;
+		if (title==null) {
+			String[] list2 = new String[list.length];
+			for (int i=0; i<list.length; i++)
+				list2[i] = list[i];
+			list = list2;
+		}
 		if (filter.length()>=2 && filter.startsWith("(")&&filter.endsWith(")")) {
 			filter = filter.substring(1,filter.length()-1);
 			isRegex = true;
-		} else
-			isRegex = false;
-		IJ.showStatus("");
-		return filter;
+		}
+		int filteredImages = 0;
+		for (int i=0; i<list.length; i++) {
+			if (isRegex && containsRegex(list[i],filter,title!=null&&title.contains("(legacy)")))
+				filteredImages++;
+			else if (list[i].contains(filter))
+				filteredImages++;
+			else
+				list[i] = null;
+		}
+		if (filteredImages==0) {
+			if (title!=null) {
+				if (isRegex)
+					IJ.error(title, "None of the file names contain the regular expression '"+filter+"'.");
+				else
+					IJ.error(title, "None of the "+list.length+" files contain '"+filter+"' in the name.");
+			}
+			return null;
+		}
+		String[] list2 = new String[filteredImages];
+		int j = 0;
+		for (int i=0; i<list.length; i++) {
+			if (list[i]!=null)
+				list2[j++] = list[i];
+		}
+		list = list2;
+		return list;
 	}
 	
-	private boolean containsRegex(String name, String regex) {
+	private static boolean containsRegex(String name, String regex, boolean legacy) {
 		boolean contains = false;
 		try {
-			if (legacyRegex!=null)
-				contains = name.matches(filter);
+			if (legacy)
+				contains = name.matches(regex);
 			else
 				contains = name.replaceAll(regex,"").length()!=name.length();
 			IJ.showStatus("");
@@ -501,6 +544,8 @@ public class FolderOpener implements PlugIn {
 		}
 	
 		void setStackInfo() {
+			if (imp==null)
+				return;
 			int width = imp.getWidth();
 			int height = imp.getHeight();
 			int depth = imp.getStackSize();
@@ -511,7 +556,6 @@ public class FolderOpener implements PlugIn {
 			double scale = getNumber(numberField.elementAt(3));
 			if (scale<5.0) scale = 5.0;
 			if (scale>100.0) scale = 100.0;
-			
 			if (n<1) n = fileCount;
 			if (start<1 || start>fileCount) start = 1;
 			if (start+n-1>fileCount)
@@ -519,17 +563,14 @@ public class FolderOpener implements PlugIn {
 			if (inc<1) inc = 1;
 			TextField tf = (TextField)stringField.elementAt(0);
 			String filter = tf.getText();
-			filter = checkForRegex(filter);
-			if (!filter.equals("") && !filter.equals("*")) {
-				int n2 = 0;
-				for (int i=0; i<list.length; i++) {
-					if (isRegex && containsRegex(list[i],filter))
-						n2++;
-					else if (list[i].indexOf(filter)>=0)
-						n2++;
-				}
-				if (n2<n) n = n2;
-			}
+			int n3 = Integer.MAX_VALUE;
+			String[] filteredList = getFilteredList(list, filter, null);
+			if (filteredList!=null)
+				n3 = filteredList.length;
+			else
+				n3 = 0;
+			if (n3<n)
+				n = n3;
 			switch (imp.getType()) {
 				case ImagePlus.GRAY16:
 					bytesPerPixel=2;break;
