@@ -72,7 +72,7 @@ public class Resizer implements PlugIn, TextListener, ItemListener  {
 				newWidth = (int)origWidth;
 				newHeight = (int)origHeight;
 			}
-			GenericDialog gd = new GenericDialog("Resize", IJ.getInstance());
+			GenericDialog gd = new GenericDialog("Resize");
 			gd.addNumericField("Width (pixels):", newWidth, 0);
 			gd.addNumericField("Height (pixels):", newHeight, 0);
 			if (imp.isHyperStack()) {
@@ -216,10 +216,7 @@ public class Resizer implements PlugIn, TextListener, ItemListener  {
 			interpolationMethod = interpolationMethod&15;
 			int stackSize = imp.getStackSize();
 			int bitDepth = imp.getBitDepth();
-			if (newDepth<=stackSize/2 && interpolationMethod==ImageProcessor.NONE)
-				imp2 = shrinkZ(imp, newDepth, inPlace);
-			else
-				imp2 = resizeZ(imp, newDepth, interpolationMethod);
+			imp2 = resizeZ(imp, newDepth, interpolationMethod);
 			if (imp2==null)
 				return null;
 			ImageProcessor ip = imp.getProcessor();
@@ -262,8 +259,6 @@ public class Resizer implements PlugIn, TextListener, ItemListener  {
 			slices2 = depth2;
 		double scale = (double)(depth2-1)/slices;
 		if (scaleT) scale = (double)(depth2-1)/frames;
-		if (scale<=0.5 && interpolationMethod==ImageProcessor.NONE)
-			return shrinkHyperstack(imp, depth2, inPlace, scaleT);
 		ImageStack stack1 = imp.getStack();
 		int width = stack1.getWidth();
 		int height = stack1.getHeight();
@@ -332,54 +327,6 @@ public class Resizer implements PlugIn, TextListener, ItemListener  {
 		return imp2;
 	}
 
-	private ImagePlus shrinkHyperstack(ImagePlus imp, int newDepth, boolean inPlace, boolean scaleT) {
-		int channels = imp.getNChannels();
-		int slices = imp.getNSlices();
-		int frames = imp.getNFrames();
-		int factor = (int)Math.round((double)slices/newDepth);
-		if (scaleT) factor = frames/newDepth;
-		int zfactor = scaleT?1:factor;
-		int tfactor = scaleT?factor:1;
-		ImageStack stack = imp.getStack();
-		ImageStack stack2 = new ImageStack(imp.getWidth(), imp.getHeight());
-		boolean virtual = stack.isVirtual();
-		int slices2 = slices/zfactor + ((slices%zfactor)!=0?1:0);
-		int frames2 = frames/tfactor + ((frames%tfactor)!=0?1:0);
-		int n = channels*slices2*frames2;
-		int count = 1;
-		for (int t=1; t<=frames; t+=tfactor) {
-			for (int z=1; z<=slices; z+=zfactor) {
-				for (int c=1; c<=channels; c++) {
-					int i = imp.getStackIndex(c, z, t);
-					IJ.showProgress(i, n);
-					ImageProcessor ip = stack.getProcessor(imp.getStackIndex(c, z, t));
-					if (!inPlace) ip=ip.duplicate();
-					//IJ.log(count++ +"  "+i+" "+c+" "+z+" "+t);
-					stack2.addSlice(stack.getSliceLabel(i), ip);
-				}
-			}
-		}
-		ImagePlus imp2 = new ImagePlus(imp.getTitle(), stack2);
-		imp2.setDimensions(channels, slices2, frames2);
-		IJ.showProgress(1.0);
-		return imp2;
-	}
-
-	private ImagePlus shrinkZ(ImagePlus imp, int newDepth, boolean inPlace) {
-		ImageStack stack = imp.getStack();
-		int factor = imp.getStackSize()/newDepth;
-		boolean virtual = stack.isVirtual();
-		int n = stack.getSize();
-		ImageStack stack2 = new ImageStack(stack.getWidth(), stack.getHeight());
-		for (int i=1; i<=n; i+=factor) {
-			if (virtual) IJ.showProgress(i, n);
-			ImageProcessor ip2 = stack.getProcessor(i);
-			if (!inPlace) ip2 = ip2.duplicate();
-			stack2.addSlice(stack.getSliceLabel(i), ip2);
-		}
-		return new ImagePlus(imp.getTitle(), stack2);
-	}
-
 	private ImagePlus resizeZ(ImagePlus imp, int newDepth, int interpolationMethod) {
 		ImageStack stack1 = imp.getStack();
 		int width = stack1.getWidth();
