@@ -18,7 +18,6 @@ public class Selection implements PlugIn, Measurements {
 	private float[] kernel = {1f, 1f, 1f, 1f, 1f};
 	private float[] kernel3 = {1f, 1f, 1f};
 	private static int bandSize = 15; // pixels
-	private static boolean nonScalable;
 	private static Color linec, fillc;
 	private static int lineWidth = 1;
 	private static boolean smooth;
@@ -290,7 +289,7 @@ public class Selection implements PlugIn, Measurements {
 		imp.setRoi(p);
 	}
 	
-	private void transferProperties(Roi roi1, Roi roi2) {
+	private static void transferProperties(Roi roi1, Roi roi2) {
 		if (roi1==null || roi2==null)
 			return;
 		roi2.setStrokeColor(roi1.getStrokeColor());
@@ -527,7 +526,7 @@ public class Selection implements PlugIn, Measurements {
 		boolean useInvertingLut = Prefs.useInvertingLut;
 		Prefs.useInvertingLut = false;
 		boolean selectAll = roi!=null && roi.getType()==Roi.RECTANGLE && roi.getBounds().width==imp.getWidth()
-			&& roi.getBounds().height==imp.getHeight() && imp.getProcessor().getMinThreshold()!=ImageProcessor.NO_THRESHOLD;
+			&& roi.getBounds().height==imp.getHeight() && imp.isThreshold();
 		if (roi==null || !(roi.isArea()||roi.getType()==Roi.POINT) || selectAll) {
 			createMaskFromThreshold(imp);
 			Prefs.useInvertingLut = useInvertingLut;
@@ -548,7 +547,14 @@ public class Selection implements PlugIn, Measurements {
 		ip.setRoi(roi);
 		ip.setValue(255);
 		ip.fill(ip.getMask());
-		maskImp.updateAndDraw();
+		Calibration cal = imp.getCalibration();
+		if (cal.scaled()) {
+			Calibration cal2 = maskImp.getCalibration();
+			cal2.pixelWidth = cal.pixelWidth;
+			cal2.pixelHeight = cal.pixelHeight;
+			cal2.setUnit(cal.getUnit());
+		}
+		maskImp.updateAndRepaintWindow();
 		Prefs.useInvertingLut = useInvertingLut;
 	}
 	
@@ -561,7 +567,7 @@ public class Selection implements PlugIn, Measurements {
 		IJ.run("Duplicate...", "title=mask");
 		ImagePlus imp2 = WindowManager.getCurrentImage();
 		ImageProcessor ip2 = imp2.getProcessor();
-		ip2.setThreshold(t1, t2, ImageProcessor.NO_LUT_UPDATE);
+		ip2.setThreshold(t1, t2, ip2.getLutUpdateMode());
 		IJ.run("Convert to Mask");
 	}
 
@@ -599,11 +605,18 @@ public class Selection implements PlugIn, Measurements {
 		imp.setRoi(s1.xor(s2));
 	}
 	
-	void lineToArea(ImagePlus imp) {
+	private void lineToArea(ImagePlus imp) {
 		Roi roi = imp.getRoi();
 		if (roi==null || !roi.isLine())
 			{IJ.error("Line to Area", "Line selection required"); return;}
 		Undo.setup(Undo.ROI, imp);
+		Roi roi2 = lineToArea(roi);
+		imp.setRoi(roi2);
+		Roi.previousRoi = (Roi)roi.clone();
+	}
+	
+	/** Converts a line selection into an area selection. */
+	public static Roi lineToArea(Roi roi) {
 		Roi roi2 = null;
 		if (roi.getType()==Roi.LINE) {
 			double width = roi.getStrokeWidth();
@@ -614,21 +627,33 @@ public class Selection implements PlugIn, Measurements {
 			roi2 = new PolygonRoi(p, Roi.POLYGON);
 			roi2.setDrawOffset(roi.getDrawOffset());
 		} else {
-			ImageProcessor ip2 = new ByteProcessor(imp.getWidth(), imp.getHeight());
+			roi = (Roi)roi.clone();
+			int lwidth = (int)roi.getStrokeWidth();
+			if (lwidth<5)
+				lwidth = 5;
+			Rectangle bounds = roi.getBounds();
+			int width = bounds.width + lwidth*2;
+			int height = bounds.height + lwidth*2;
+			ImageProcessor ip2 = new ByteProcessor(width, height);
+			roi.setLocation(lwidth, lwidth);
 			ip2.setColor(255);
 			roi.drawPixels(ip2);
-			//new ImagePlus("ip2", ip2.duplicate()).show();
 			ip2.setThreshold(255, 255, ImageProcessor.NO_LUT_UPDATE);
 			ThresholdToSelection tts = new ThresholdToSelection();
 			roi2 = tts.convert(ip2);
+			if (roi2==null)
+				return roi;
+			if (bounds.x==0&&bounds.y==0)
+				roi2.setLocation(0, 0);
+			else
+				roi2.setLocation(bounds.x-lwidth/2, bounds.y-lwidth/2);
 		}
 		transferProperties(roi, roi2);
 		roi2.setStrokeWidth(0);
 		Color c = roi2.getStrokeColor();
 		if (c!=null)  // remove any transparency
 			roi2.setStrokeColor(new Color(c.getRed(),c.getGreen(),c.getBlue()));
-		imp.setRoi(roi2);
-		Roi.previousRoi = (Roi)roi.clone();
+		return roi2;
 	}
 	
 	void areaToLine(ImagePlus imp) {
@@ -705,6 +730,10 @@ public class Selection implements PlugIn, Measurements {
 	}
 	
 	boolean setProperties(String title, Roi roi) {
+		if ((roi instanceof PointRoi) && Toolbar.getMultiPointMode() && IJ.altKeyDown()) {
+			((PointRoi)roi).displayCounts();
+			return true;
+		}
 		Frame f = WindowManager.getFrontWindow();
 		if (f!=null && f.getTitle().indexOf("3D Viewer")!=-1)
 			return false;
