@@ -10,14 +10,13 @@ import ij.util.Tools;
 import ij.text.*;
 import ij.macro.*;
 import ij.plugin.MacroInstaller;
-import ij.plugin.NewPlugin;
 import ij.plugin.Commands;
 import ij.plugin.Macro_Runner;
 import ij.io.SaveDialog;
 
 /** This is a simple TextArea based editor for editing and compiling plugins. */
 public class Editor extends PlugInFrame implements ActionListener, ItemListener,
-	TextListener, ClipboardOwner, MacroConstants, Runnable {
+	TextListener, ClipboardOwner, MacroConstants, Runnable, Debugger {
 	
 	/** ImportPackage statements added in front of scripts. Contains no 
 	newlines so that lines numbers in error messages are not changed. */
@@ -38,7 +37,7 @@ public class Editor extends PlugInFrame implements ActionListener, ItemListener,
 		"importPackage(java.util);"+
 		"importPackage(java.io);"+
 		"function print(s) {IJ.log(s);};";
-		
+
 	public static final int MAX_SIZE=28000, XINC=10, YINC=18;
 	public static final int MONOSPACED=1, MENU_BAR=2;
 	public static final int MACROS_MENU_ITEMS = 12;
@@ -85,6 +84,7 @@ public class Editor extends PlugInFrame implements ActionListener, ItemListener,
     private FunctionFinder functionFinder;
     private ArrayList undoBuffer = new ArrayList();
     private boolean performingUndo;
+    private boolean checkForCurlyQuotes;
 	
 	public Editor() {
 		this(16, 60, 0, MENU_BAR);
@@ -133,7 +133,7 @@ public class Editor extends PlugInFrame implements ActionListener, ItemListener,
 		boolean shortcutsBroken = IJ.isWindows()
 			&& (System.getProperty("java.version").indexOf("1.1.8")>=0
 			||System.getProperty("java.version").indexOf("1.5.")>=0);
-shortcutsBroken = false;
+		shortcutsBroken = false;
 		if (shortcutsBroken)
 			item = new MenuItem("Cut  Ctrl+X");
 		else
@@ -175,7 +175,10 @@ shortcutsBroken = false;
 		m.add(new MenuItem("Save Settings"));
 		m.addActionListener(this);
 		mb.add(m);
-	}
+		
+		m = Menus.getExamplesMenu(this);
+		mb.add(m);
+	}			
 			
 	public void positionWindow() {
 		Dimension screen = IJ.getScreenSize();
@@ -246,6 +249,7 @@ shortcutsBroken = false;
 			dontShowWindow = false;
 		}
 		WindowManager.setWindow(this);
+		checkForCurlyQuotes = true;
 		changes = false;
 	}
 
@@ -273,6 +277,10 @@ shortcutsBroken = false;
 	public void open(String dir, String name) {
 		path = dir+name;
 		File file = new File(path);
+		if (!file.exists()) {
+			IJ.error("File not found: "+path);
+			return;
+		}
 		try {
 			StringBuffer sb = new StringBuffer(5000);
 			BufferedReader r = new BufferedReader(new FileReader(file));
@@ -355,12 +363,14 @@ shortcutsBroken = false;
 			save();
 			String text = ta.getText();
 			if (text.contains("implements PlugInFilter") && text.contains("IJ.run("))
-				IJ.log("Plugins that call IJ.run() should probably implement PlugIn, not PlugInFilter.");
+				IJ.log("<<Plugins that call IJ.run() should probably implement PlugIn, not PlugInFilter.>>");
 			IJ.runPlugIn("ij.plugin.Compiler", path);
 		}
 	}
 	
 	final void runMacro(boolean debug) {
+		if (path!=null)
+			Macro_Runner.setFilePath(path);
 		if (getTitle().endsWith(".js"))
 			{evaluateJavaScript(); return;}
 		else if (getTitle().endsWith(".bsh"))
@@ -374,6 +384,28 @@ shortcutsBroken = false;
 			text = ta.getText();
 		else
 			text = ta.getSelectedText();
+		Interpreter instance = Interpreter.getInstance();
+		if (instance!=null) { // abort any currently running macro
+			instance.abortMacro();
+			long t0 = System.currentTimeMillis();
+			while (Interpreter.getInstance()!=null && (System.currentTimeMillis()-t0)<3000L)
+				IJ.wait(10);
+		}
+		if (checkForCurlyQuotes && text.contains("\u201D")) {
+			// replace curly quotes with standard quotes
+ 			text = text.replaceAll("\u201C", "\""); 
+			text = text.replaceAll("\u201D", "\"");
+			if (start==end)
+				ta.setText(text);
+			else {
+				String text2 = ta.getText();
+ 				text2 = text2.replaceAll("\u201C", "\""); 
+				text2 = text2.replaceAll("\u201D", "\"");
+				ta.setText(text2);
+			}
+			changes = true;
+			checkForCurlyQuotes = false;
+		}
 		new MacroRunner(text, debug?this:null);
 	}
 	
@@ -387,23 +419,31 @@ shortcutsBroken = false;
 			text = ta.getText();
 		else
 			text = ta.getSelectedText();
-		if (text.equals("")) return;
+		if (text.equals(""))
+			return;
 		text = getJSPrefix("") + text;
-		if (IJ.isJava16() && !(IJ.isMacOSX()&&!IJ.is64Bit()))
-			IJ.runPlugIn("JavaScriptEvaluator", text);
-		else {
+		if (IJ.isJava18())
+			text = "load(\"nashorn:mozilla_compat.js\");" + text;
+		if ((IJ.isJava16() && !(IJ.isMacOSX()&&!IJ.is64Bit()))) {
+			// Use JavaScript engine built into Java 6 and later.
+			IJ.runPlugIn("ij.plugin.JavaScriptEvaluator", text);
+		} else {
 			Object js = IJ.runPlugIn("JavaScript", text);
 			if (js==null)
 				download("/download/tools/JavaScript.jar");
 		}
 	}
 
-	void evaluateScript(String ext) {
+	public void evaluateScript(String ext) {
 		if (downloading) {
 			IJ.beep();
 			IJ.showStatus("Download in progress");
 			return;
 		}
+		if (ext.endsWith(".js")) {
+			evaluateJavaScript();
+			return;
+		}
 		if (!getTitle().endsWith(ext))
 			setTitle(SaveDialog.setExtension(getTitle(), ext));
 		int start = ta.getSelectionStart();
@@ -597,6 +637,7 @@ shortcutsBroken = false;
 		ta.replaceRange(s, start, end);
 		if (IJ.isMacOSX())
 			ta.setCaretPosition(start+s.length());
+		checkForCurlyQuotes = true;
 	}
 
 	void copyToInfo() { 
@@ -619,7 +660,6 @@ shortcutsBroken = false;
 		String what = e.getActionCommand();
 		int flags = e.getModifiers();
 		boolean altKeyDown = (flags & Event.ALT_MASK)!=0;
-		if (IJ.debugMode) IJ.log("actionPerformed: "+e);
 		
 		if ("Save".equals(what))
 			save();
@@ -635,13 +675,13 @@ shortcutsBroken = false;
 				enableDebugging();
 				runMacro(true);
 		} else if ("Step".equals(what))
-			setDebugMode(Interpreter.STEP);
+			setDebugMode(STEP);
 		else if ("Trace".equals(what))
-			setDebugMode(Interpreter.TRACE);
+			setDebugMode(TRACE);
 		else if ("Fast Trace".equals(what))
-			setDebugMode(Interpreter.FAST_TRACE);
+			setDebugMode(FAST_TRACE);
 		else if ("Run".equals(what))
-			setDebugMode(Interpreter.RUN);
+			setDebugMode(RUN_TO_COMPLETION);
 		else if ("Run to Insertion Point".equals(what))
 			runToInsertionPoint();
 		else if ("Abort".equals(what) || "Abort Macro".equals(what)) {
@@ -701,6 +741,8 @@ shortcutsBroken = false;
 			IJ.open();
 		else if (what.equals("Copy to Image Info"))
 			copyToInfo();
+		else if (what.endsWith(".ijm") || what.endsWith(".java") || what.endsWith(".js") || what.endsWith(".bsh") || what.endsWith(".py"))
+			openExample(what, e);
 		else {
 			if (altKeyDown) {
 				enableDebugging();
@@ -710,6 +752,54 @@ shortcutsBroken = false;
 		}
 	}
 	
+	private void openExample(String name, ActionEvent e) {
+		boolean isJava = name.endsWith(".java");
+		boolean isJavaScript = name.endsWith(".js");
+		boolean isBeanShell = name.endsWith(".bsh");
+		boolean isPython = name.endsWith(".py");
+		int flags = e.getModifiers();
+		boolean shift = (flags & KeyEvent.SHIFT_MASK) != 0;
+		boolean control = (flags & KeyEvent.CTRL_MASK) != 0;
+		boolean alt = (flags & KeyEvent.ALT_MASK) != 0;
+		boolean run = !isJava && (Prefs.autoRunExamples||shift||control||alt);
+		int rows = 24;
+		int columns = 70;
+		int options = MENU_BAR;
+		String text = null;
+		Editor ed = new Editor(rows, columns, 0, options);
+		String dir = "Macro/";
+		if (isJava)
+			dir = "Java/";
+		else if (isJavaScript)
+			dir = "JavaScript/";
+		else if (isBeanShell)
+			dir = "BeanShell/";
+		else if (isPython)
+			dir = "Python/";
+		String url = "http://wsr.imagej.net/download/Examples/"+dir+name;
+		text = IJ.openUrlAsString(url);
+		if (text.startsWith("<Error: ")) {
+			IJ.error("Open Example", text);
+			return;
+		}
+		if (ta!=null && ta.getText().length()==0 && !(isJava||isJavaScript||isBeanShell||isPython)) {
+			ta.setText(text);
+			ta.setCaretPosition(0);
+			setTitle(name);
+		} else
+			ed.create(name, text);
+		if (run) {
+			if (isJavaScript)
+				ed.evaluateJavaScript();
+			else if (isBeanShell)
+				ed.evaluateScript(".bsh");
+			else if (isPython)
+				ed.evaluateScript(".py");
+			else
+				IJ.runMacro(text);
+		}
+	}
+	
 	protected void showMacroFunctions() {
 		String url= "/developer/macro/functions.html";
 		String selText = ta.getSelectedText().replace("\n", " ");
@@ -725,8 +815,7 @@ shortcutsBroken = false;
 			IJ.beep();
 		else {
 			runToLine = getCurrentLine();
-			//IJ.log("runToLine: "+runToLine);
-			setDebugMode(Interpreter.RUN_TO_CARET);
+			setDebugMode(RUN_TO_CARET);
 		}
 	}
 		
@@ -759,11 +848,6 @@ shortcutsBroken = false;
 
 	final void enableDebugging() {
 			step = true;
-			Interpreter interp = Interpreter.getInstance();
-			if (interp!=null && interp.getEditor()==this) {
-				interp.abort();
-				IJ.wait(100);
-			}
 			int start = ta.getSelectionStart();
 			int end = ta.getSelectionEnd();
 			if (start==debugStart && end==debugEnd)
@@ -774,13 +858,14 @@ shortcutsBroken = false;
 		step = true;
 		Interpreter interp = Interpreter.getInstance();
 		if (interp!=null) {
-			interp.setEditor(this);
+			if (interp.getDebugger()==null)
+				fixLineEndings();
+			interp.setDebugger(this);
 			interp.setDebugMode(mode);
 		}
 	}
 
 	public void textValueChanged(TextEvent e) {
-		if (IJ.debugMode) IJ.log("textValueChanged1: "+undoBuffer.size());
 		String text = ta.getText();
 		//if (undo2==null || text.length()!=undo2.length()+1 || text.charAt(text.length()-1)=='\n')
 		int length = 0;
@@ -794,7 +879,6 @@ shortcutsBroken = false;
 					undoBuffer.set(i-1, undoBuffer.get(i));
 				undoBuffer.set(undoBuffer.size()-1, text);
 			}
-			if (IJ.debugMode) IJ.log("textValueChanged2: "+undoBuffer.size()+" "+text);
 		}
 		performingUndo = false;
 		if (isMacroWindow) return;
@@ -814,6 +898,7 @@ shortcutsBroken = false;
 	/** Override windowActivated in PlugInFrame to
 		prevent Mac menu bar from being installed. */
 	public void windowActivated(WindowEvent e) {
+			if (IJ.debugMode) IJ.log("Editor.windowActivated");
 			WindowManager.setWindow(this);
 			instance = this;
 	}
@@ -822,7 +907,7 @@ shortcutsBroken = false;
 	public void close() {
 		boolean okayToClose = true;
 		ImageJ ij = IJ.getInstance();
-		if (!getTitle().equals("Errors") && changes && !IJ.isMacro() && ij!=null) {
+		if (!getTitle().equals("Errors") && changes && !IJ.isMacro() && ij!=null && !ij.quittingViaMacro()) {
 			String msg = "Save changes to \"" + getTitle() + "\"?";
 			YesNoCancelDialog d = new YesNoCancelDialog(this, "Editor", msg);
 			if (d.cancelPressed())
@@ -1114,7 +1199,6 @@ shortcutsBroken = false;
 			if (!inQuotes && c!='\n' && c!='\t' && (c<32||c>127)) {
 				count++;
 				chars[i] = ' ';
-				//IJ.log(""+(0+c));
 			}
 		}
 		if (count>0) {
@@ -1186,25 +1270,29 @@ shortcutsBroken = false;
 	public int debug(Interpreter interp, int mode) {
 		if (IJ.debugMode)
 			IJ.log("debug: "+interp.getLineNumber()+"  "+mode+"  "+interp);
-		if (mode==Interpreter.RUN)
+		if (mode==RUN_TO_COMPLETION)
 			return 0;
-		if (!isVisible()) { // abort macro if user closes window
-			interp.abortMacro();
-			return 0;
-		}
-		if (!isActive())
-			toFront();
 		int n = interp.getLineNumber();
-		if (n==previousLine)
-			{previousLine=0; return 0;}
-		previousLine = n;
-		if (mode==Interpreter.RUN_TO_CARET) {
+		if (mode==RUN_TO_CARET) {
 			if (n==runToLine) {
-				mode = Interpreter.STEP;
+				mode = STEP;
 				interp.setDebugMode(mode);
 			} else
 				return 0;
 		}
+		if (!isVisible()) { // abort macro if user closes window
+			interp.abortMacro();
+			return 0;
+		}
+		if (n==previousLine) {
+			previousLine=0;
+			return 0;
+		}
+		Window win = WindowManager.getActiveWindow();
+		if (win!=this)
+			IJ.wait(50);
+		toFront();
+		previousLine = n;
 		String text = ta.getText();
 		if (IJ.isWindows())
 			text = text.replaceAll("\r\n", "\n");
@@ -1229,21 +1317,20 @@ shortcutsBroken = false;
 			return 0; // skip code added with Interpreter.setAdditionalFunctions()
 		ta.select(debugStart, debugEnd);
 		if (debugWindow!=null && !debugWindow.isShowing()) {
-			interp.setEditor(null);
+			interp.setDebugger(null);
 			debugWindow = null;
 		} else
 			debugWindow = interp.updateDebugWindow(interp.getVariables(), debugWindow);
 		if (debugWindow!=null) {
 			interp.updateArrayInspector();
-			if (!isActive())
-				toFront();
+			toFront();
 		}
-		if (mode==Interpreter.STEP) {
+		if (mode==STEP) {
 			step = false;
 			while (!step && !interp.done() && isVisible())
 				IJ.wait(5);
 		} else {
-			if (mode==Interpreter.FAST_TRACE)
+			if (mode==FAST_TRACE)
 				IJ.wait(5);
 			else
 				IJ.wait(150);
